CFAllocator

Struct CFAllocator 

pub struct CFAllocator { /* private fields */ }
Implementations

Source

impl CFAllocator

pub fn set_default(allocator: Option<&CFAllocator>)

pub fn default() -> Option<CFRetained<CFAllocator>>

pub unsafe fn new( allocator: Option<&CFAllocator>, context: *mut CFAllocatorContext, ) -> Option<CFRetained<CFAllocator>>

Safety
  • allocator might not allow None.
  • context must be a valid pointer.
pub unsafe fn with_zone( allocator: Option<&CFAllocator>, zone: *mut malloc_zone_t, ) -> Option<CFRetained<CFAllocator>>

Available on crate feature libc only.
Safety
  • allocator might not allow None.
  • zone must be a valid pointer.
pub unsafe fn allocate_typed( allocator: Option<&CFAllocator>, size: CFIndex, descriptor: CFAllocatorTypeID, hint: CFOptionFlags, ) -> *mut c_void

Safety

allocator might not allow None.

pub unsafe fn reallocate_typed( allocator: Option<&CFAllocator>, ptr: *mut c_void, newsize: CFIndex, descriptor: CFAllocatorTypeID, hint: CFOptionFlags, ) -> *mut c_void

Safety
  • allocator might not allow None.
  • ptr must be a valid pointer.
pub fn allocate_bytes( allocator: Option<&CFAllocator>, size: CFIndex, hint: CFOptionFlags, ) -> *mut c_void

pub unsafe fn reallocate_bytes( allocator: Option<&CFAllocator>, ptr: *mut c_void, newsize: CFIndex, hint: CFOptionFlags, ) -> *mut c_void

Safety
  • allocator might not allow None.
  • ptr must be a valid pointer.
pub fn allocate( allocator: Option<&CFAllocator>, size: CFIndex, hint: CFOptionFlags, ) -> *mut c_void

pub unsafe fn reallocate( allocator: Option<&CFAllocator>, ptr: *mut c_void, newsize: CFIndex, hint: CFOptionFlags, ) -> *mut c_void

Safety
  • allocator might not allow None.
  • ptr must be a valid pointer.
pub unsafe fn deallocate(allocator: Option<&CFAllocator>, ptr: *mut c_void)

Safety
  • allocator might not allow None.
  • ptr must be a valid pointer.
pub fn preferred_size_for_size( allocator: Option<&CFAllocator>, size: CFIndex, hint: CFOptionFlags, ) -> CFIndex

pub unsafe fn context( allocator: Option<&CFAllocator>, context: *mut CFAllocatorContext, )

Safety
  • allocator might not allow None.
  • context must be a valid pointer.

Methods from Deref<Target = CFType>

pub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>

Attempt to downcast the type to that of type T.

This is the reference-variant. Use CFRetained::downcast if you want to convert a retained type. See also ConcreteType for more details on which types support being converted to.

pub fn retain_count(&self) -> usize

Get the reference count of the object.

This function may be useful for debugging. You normally do not use this function otherwise.

Beware that some things (like CFNumbers, small CFStrings etc.) may not have a normal retain count for optimization purposes, and can return usize::MAX in that case.