pub struct CFFileSecurity { /* private fields */ }CFFileSecurity only.Expand description
This is toll-free bridged with NSFileSecurity.
Implementations
Sourceimpl CFFileSecurity
impl CFFileSecurity
pub fn new( allocator: Option<&CFAllocator>, ) -> Option<CFRetained<CFFileSecurity>>
pub fn new_copy( allocator: Option<&CFAllocator>, file_sec: Option<&CFFileSecurity>, ) -> Option<CFRetained<CFFileSecurity>>
Sourcepub unsafe fn owner_uuid(&self, owner_uuid: *mut *const CFUUID) -> bool
Available on crate feature CFUUID only.
pub unsafe fn owner_uuid(&self, owner_uuid: *mut *const CFUUID) -> bool
CFUUID only.Safety
owner_uuid must be a valid pointer.
pub fn set_owner_uuid(&self, owner_uuid: Option<&CFUUID>) -> bool
CFUUID only.Sourcepub unsafe fn group_uuid(&self, group_uuid: *mut *const CFUUID) -> bool
Available on crate feature CFUUID only.
pub unsafe fn group_uuid(&self, group_uuid: *mut *const CFUUID) -> bool
CFUUID only.Safety
group_uuid must be a valid pointer.
pub fn set_group_uuid(&self, group_uuid: Option<&CFUUID>) -> bool
CFUUID only.Sourcepub unsafe fn owner(&self, owner: *mut uid_t) -> bool
Available on crate feature libc only.
pub unsafe fn owner(&self, owner: *mut uid_t) -> bool
libc only.Safety
owner must be a valid pointer.
pub fn set_owner(&self, owner: uid_t) -> bool
libc only.Sourcepub unsafe fn group(&self, group: *mut gid_t) -> bool
Available on crate feature libc only.
pub unsafe fn group(&self, group: *mut gid_t) -> bool
libc only.Safety
group must be a valid pointer.
pub fn set_group(&self, group: gid_t) -> bool
libc only.Sourcepub unsafe fn mode(&self, mode: *mut mode_t) -> bool
Available on crate feature libc only.
pub unsafe fn mode(&self, mode: *mut mode_t) -> bool
libc only.Safety
mode must be a valid pointer.
pub fn set_mode(&self, mode: mode_t) -> bool
libc only.Sourceimpl CFFileSecurity
impl CFFileSecurity
pub fn clear_properties( &self, clear_property_mask: CFFileSecurityClearOptions, ) -> bool
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
pub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.