pub struct CFMutableBitVector { /* private fields */ }CFBitVector only.Expand description
Implementations
Sourceimpl CFMutableBitVector
impl CFMutableBitVector
Sourcepub unsafe fn new(
allocator: Option<&CFAllocator>,
capacity: CFIndex,
) -> Option<CFRetained<CFMutableBitVector>>
pub unsafe fn new( allocator: Option<&CFAllocator>, capacity: CFIndex, ) -> Option<CFRetained<CFMutableBitVector>>
Safety
allocator might not allow None.
Sourcepub unsafe fn new_copy(
allocator: Option<&CFAllocator>,
capacity: CFIndex,
bv: Option<&CFBitVector>,
) -> Option<CFRetained<CFMutableBitVector>>
pub unsafe fn new_copy( allocator: Option<&CFAllocator>, capacity: CFIndex, bv: Option<&CFBitVector>, ) -> Option<CFRetained<CFMutableBitVector>>
Safety
allocatormight not allowNone.bvmight not allowNone.
Sourceimpl CFMutableBitVector
impl CFMutableBitVector
Sourcepub unsafe fn set_count(bv: Option<&CFMutableBitVector>, count: CFIndex)
pub unsafe fn set_count(bv: Option<&CFMutableBitVector>, count: CFIndex)
Safety
bv might not allow None.
Sourcepub unsafe fn flip_bit_at_index(bv: Option<&CFMutableBitVector>, idx: CFIndex)
pub unsafe fn flip_bit_at_index(bv: Option<&CFMutableBitVector>, idx: CFIndex)
Safety
bv might not allow None.
Sourcepub unsafe fn flip_bits(bv: Option<&CFMutableBitVector>, range: CFRange)
pub unsafe fn flip_bits(bv: Option<&CFMutableBitVector>, range: CFRange)
Safety
bv might not allow None.
Sourcepub unsafe fn set_bit_at_index(
bv: Option<&CFMutableBitVector>,
idx: CFIndex,
value: CFBit,
)
pub unsafe fn set_bit_at_index( bv: Option<&CFMutableBitVector>, idx: CFIndex, value: CFBit, )
Safety
bv might not allow None.
Sourcepub unsafe fn set_bits(
bv: Option<&CFMutableBitVector>,
range: CFRange,
value: CFBit,
)
pub unsafe fn set_bits( bv: Option<&CFMutableBitVector>, range: CFRange, value: CFBit, )
Safety
bv might not allow None.
Sourcepub unsafe fn set_all_bits(bv: Option<&CFMutableBitVector>, value: CFBit)
pub unsafe fn set_all_bits(bv: Option<&CFMutableBitVector>, value: CFBit)
Safety
bv might not allow None.
Methods from Deref<Target = CFBitVector>
pub fn count(&self) -> CFIndex
pub fn count_of_bit(&self, range: CFRange, value: CFBit) -> CFIndex
pub fn contains_bit(&self, range: CFRange, value: CFBit) -> bool
pub fn bit_at_index(&self, idx: CFIndex) -> CFBit
Sourcepub unsafe fn bits(&self, range: CFRange, bytes: *mut u8)
pub unsafe fn bits(&self, range: CFRange, bytes: *mut u8)
Safety
bytes must be a valid pointer.
pub fn first_index_of_bit(&self, range: CFRange, value: CFBit) -> CFIndex
pub fn last_index_of_bit(&self, range: CFRange, value: CFBit) -> CFIndex
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
pub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.