pub struct CFXMLNode { /* private fields */ }CFXMLNode only.Expand description
Implementations
Sourceimpl CFXMLNode
impl CFXMLNode
Sourcepub unsafe fn new(
alloc: Option<&CFAllocator>,
xml_type: CFXMLNodeTypeCode,
data_string: Option<&CFString>,
additional_info_ptr: *const c_void,
version: CFIndex,
) -> Option<CFRetained<CFXMLNode>>
👎Deprecated: CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub unsafe fn new( alloc: Option<&CFAllocator>, xml_type: CFXMLNodeTypeCode, data_string: Option<&CFString>, additional_info_ptr: *const c_void, version: CFIndex, ) -> Option<CFRetained<CFXMLNode>>
CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Safety
allocmight not allowNone.data_stringmight not allowNone.additional_info_ptrmust be a valid pointer.
Sourcepub unsafe fn new_copy(
alloc: Option<&CFAllocator>,
orig_node: Option<&CFXMLNode>,
) -> Option<CFRetained<CFXMLNode>>
👎Deprecated: CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub unsafe fn new_copy( alloc: Option<&CFAllocator>, orig_node: Option<&CFXMLNode>, ) -> Option<CFRetained<CFXMLNode>>
CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Safety
allocmight not allowNone.orig_nodemight not allowNone.
pub fn type_code(&self) -> CFXMLNodeTypeCode
CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub fn string(&self) -> Option<CFRetained<CFString>>
CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub fn info_ptr(&self) -> *const c_void
CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub fn version(&self) -> CFIndex
CFXMLNode is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
pub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.