pub struct CFXMLParser { /* private fields */ }CFXMLParser only.Expand description
Implementations
Sourceimpl CFXMLParser
impl CFXMLParser
Sourcepub unsafe fn new(
allocator: Option<&CFAllocator>,
xml_data: Option<&CFData>,
data_source: Option<&CFURL>,
parse_options: CFOptionFlags,
version_of_nodes: CFIndex,
call_backs: *mut CFXMLParserCallBacks,
context: *mut CFXMLParserContext,
) -> Option<CFRetained<CFXMLParser>>
👎Deprecated: CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Available on crate features CFData and CFURL and CFXMLNode only.
pub unsafe fn new( allocator: Option<&CFAllocator>, xml_data: Option<&CFData>, data_source: Option<&CFURL>, parse_options: CFOptionFlags, version_of_nodes: CFIndex, call_backs: *mut CFXMLParserCallBacks, context: *mut CFXMLParserContext, ) -> Option<CFRetained<CFXMLParser>>
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
CFData and CFURL and CFXMLNode only.Safety
allocatormight not allowNone.xml_datamight not allowNone.data_sourcemight not allowNone.call_backsmust be a valid pointer.contextmust be a valid pointer.
Sourcepub unsafe fn with_data_from_url(
allocator: Option<&CFAllocator>,
data_source: Option<&CFURL>,
parse_options: CFOptionFlags,
version_of_nodes: CFIndex,
call_backs: *mut CFXMLParserCallBacks,
context: *mut CFXMLParserContext,
) -> Option<CFRetained<CFXMLParser>>
👎Deprecated: CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Available on crate features CFData and CFURL and CFXMLNode only.
pub unsafe fn with_data_from_url( allocator: Option<&CFAllocator>, data_source: Option<&CFURL>, parse_options: CFOptionFlags, version_of_nodes: CFIndex, call_backs: *mut CFXMLParserCallBacks, context: *mut CFXMLParserContext, ) -> Option<CFRetained<CFXMLParser>>
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
CFData and CFURL and CFXMLNode only.Safety
allocatormight not allowNone.data_sourcemight not allowNone.call_backsmust be a valid pointer.contextmust be a valid pointer.
Sourcepub unsafe fn context(&self, context: *mut CFXMLParserContext)
👎Deprecated: CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub unsafe fn context(&self, context: *mut CFXMLParserContext)
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Safety
context must be a valid pointer.
Sourcepub unsafe fn call_backs(&self, call_backs: *mut CFXMLParserCallBacks)
👎Deprecated: CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Available on crate features CFData and CFURL and CFXMLNode only.
pub unsafe fn call_backs(&self, call_backs: *mut CFXMLParserCallBacks)
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
CFData and CFURL and CFXMLNode only.Safety
call_backs must be a valid pointer.
pub fn source_url(&self) -> Option<CFRetained<CFURL>>
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
CFURL only.pub fn location(&self) -> CFIndex
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub fn line_number(&self) -> CFIndex
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub fn document(&self) -> *mut c_void
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub fn status_code(&self) -> CFXMLParserStatusCode
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub fn error_description(&self) -> Option<CFRetained<CFString>>
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Sourcepub unsafe fn abort(
&self,
error_code: CFXMLParserStatusCode,
error_description: Option<&CFString>,
)
👎Deprecated: CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
pub unsafe fn abort( &self, error_code: CFXMLParserStatusCode, error_description: Option<&CFString>, )
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Safety
error_description might not allow None.
pub fn parse(&self) -> bool
CFXMLParser is deprecated, use NSXMLParser, NSXMLDocument or libxml2 library instead
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
pub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.