pub struct CFAllocator { /* private fields */ }Expand description
Implementations
Sourceimpl CFAllocator
impl CFAllocator
pub fn set_default(allocator: Option<&CFAllocator>)
pub fn default() -> Option<CFRetained<CFAllocator>>
Sourcepub unsafe fn new(
allocator: Option<&CFAllocator>,
context: *mut CFAllocatorContext,
) -> Option<CFRetained<CFAllocator>>
pub unsafe fn new( allocator: Option<&CFAllocator>, context: *mut CFAllocatorContext, ) -> Option<CFRetained<CFAllocator>>
Safety
allocatormight not allowNone.contextmust be a valid pointer.
Sourcepub unsafe fn with_zone(
allocator: Option<&CFAllocator>,
zone: *mut malloc_zone_t,
) -> Option<CFRetained<CFAllocator>>
Available on crate feature libc only.
pub unsafe fn with_zone( allocator: Option<&CFAllocator>, zone: *mut malloc_zone_t, ) -> Option<CFRetained<CFAllocator>>
libc only.Safety
allocatormight not allowNone.zonemust be a valid pointer.
Sourcepub unsafe fn allocate_typed(
allocator: Option<&CFAllocator>,
size: CFIndex,
descriptor: CFAllocatorTypeID,
hint: CFOptionFlags,
) -> *mut c_void
pub unsafe fn allocate_typed( allocator: Option<&CFAllocator>, size: CFIndex, descriptor: CFAllocatorTypeID, hint: CFOptionFlags, ) -> *mut c_void
Safety
allocator might not allow None.
Sourcepub unsafe fn reallocate_typed(
allocator: Option<&CFAllocator>,
ptr: *mut c_void,
newsize: CFIndex,
descriptor: CFAllocatorTypeID,
hint: CFOptionFlags,
) -> *mut c_void
pub unsafe fn reallocate_typed( allocator: Option<&CFAllocator>, ptr: *mut c_void, newsize: CFIndex, descriptor: CFAllocatorTypeID, hint: CFOptionFlags, ) -> *mut c_void
Safety
allocatormight not allowNone.ptrmust be a valid pointer.
pub fn allocate_bytes( allocator: Option<&CFAllocator>, size: CFIndex, hint: CFOptionFlags, ) -> *mut c_void
Sourcepub unsafe fn reallocate_bytes(
allocator: Option<&CFAllocator>,
ptr: *mut c_void,
newsize: CFIndex,
hint: CFOptionFlags,
) -> *mut c_void
pub unsafe fn reallocate_bytes( allocator: Option<&CFAllocator>, ptr: *mut c_void, newsize: CFIndex, hint: CFOptionFlags, ) -> *mut c_void
Safety
allocatormight not allowNone.ptrmust be a valid pointer.
pub fn allocate( allocator: Option<&CFAllocator>, size: CFIndex, hint: CFOptionFlags, ) -> *mut c_void
Sourcepub unsafe fn reallocate(
allocator: Option<&CFAllocator>,
ptr: *mut c_void,
newsize: CFIndex,
hint: CFOptionFlags,
) -> *mut c_void
pub unsafe fn reallocate( allocator: Option<&CFAllocator>, ptr: *mut c_void, newsize: CFIndex, hint: CFOptionFlags, ) -> *mut c_void
Safety
allocatormight not allowNone.ptrmust be a valid pointer.
Sourcepub unsafe fn deallocate(allocator: Option<&CFAllocator>, ptr: *mut c_void)
pub unsafe fn deallocate(allocator: Option<&CFAllocator>, ptr: *mut c_void)
Safety
allocatormight not allowNone.ptrmust be a valid pointer.
pub fn preferred_size_for_size( allocator: Option<&CFAllocator>, size: CFIndex, hint: CFOptionFlags, ) -> CFIndex
Sourcepub unsafe fn context(
allocator: Option<&CFAllocator>,
context: *mut CFAllocatorContext,
)
pub unsafe fn context( allocator: Option<&CFAllocator>, context: *mut CFAllocatorContext, )
Safety
allocatormight not allowNone.contextmust be a valid pointer.
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
pub fn downcast_ref<T: ConcreteType>(&self) -> Option<&T>
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.